# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['StandaloneGatewayArgs', 'StandaloneGateway']

@pulumi.input_type
class StandaloneGatewayArgs:
    def __init__(__self__, *,
                 resource_group_name: pulumi.Input[_builtins.str],
                 sku: pulumi.Input['StandaloneGatewaySkuArgs'],
                 backend_subnet_id: Optional[pulumi.Input[_builtins.str]] = None,
                 location: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 virtual_network_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a StandaloneGateway resource.

        :param pulumi.Input[_builtins.str] resource_group_name: Specifies the name of the Resource Group where the API Management Standalone Gateway should exist. Changing this forces a new resource to be created.
        :param pulumi.Input['StandaloneGatewaySkuArgs'] sku: A `sku` block as defined below.
        :param pulumi.Input[_builtins.str] backend_subnet_id: Specifies the subnet ID in which the backend systems are hosted. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] location: Specifies the Azure Region where the API Management Standalone Gateway should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] name: Specifies the name which should be used for this API Management Standalone Gateway. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: A mapping of tags which should be assigned to the API Management Standalone Gateway. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] virtual_network_type: Specifies the type of VPN in which API Management gateway needs to be configured. Possible values are `External` and `Internal`. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        pulumi.set(__self__, "sku", sku)
        if backend_subnet_id is not None:
            pulumi.set(__self__, "backend_subnet_id", backend_subnet_id)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if virtual_network_type is not None:
            pulumi.set(__self__, "virtual_network_type", virtual_network_type)

    @_builtins.property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Input[_builtins.str]:
        """
        Specifies the name of the Resource Group where the API Management Standalone Gateway should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "resource_group_name", value)

    @_builtins.property
    @pulumi.getter
    def sku(self) -> pulumi.Input['StandaloneGatewaySkuArgs']:
        """
        A `sku` block as defined below.
        """
        return pulumi.get(self, "sku")

    @sku.setter
    def sku(self, value: pulumi.Input['StandaloneGatewaySkuArgs']):
        pulumi.set(self, "sku", value)

    @_builtins.property
    @pulumi.getter(name="backendSubnetId")
    def backend_subnet_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the subnet ID in which the backend systems are hosted. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "backend_subnet_id")

    @backend_subnet_id.setter
    def backend_subnet_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "backend_subnet_id", value)

    @_builtins.property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the Azure Region where the API Management Standalone Gateway should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "location", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the name which should be used for this API Management Standalone Gateway. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        A mapping of tags which should be assigned to the API Management Standalone Gateway. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="virtualNetworkType")
    def virtual_network_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the type of VPN in which API Management gateway needs to be configured. Possible values are `External` and `Internal`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "virtual_network_type")

    @virtual_network_type.setter
    def virtual_network_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "virtual_network_type", value)


@pulumi.input_type
class _StandaloneGatewayState:
    def __init__(__self__, *,
                 backend_subnet_id: Optional[pulumi.Input[_builtins.str]] = None,
                 location: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 sku: Optional[pulumi.Input['StandaloneGatewaySkuArgs']] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 virtual_network_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering StandaloneGateway resources.

        :param pulumi.Input[_builtins.str] backend_subnet_id: Specifies the subnet ID in which the backend systems are hosted. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] location: Specifies the Azure Region where the API Management Standalone Gateway should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] name: Specifies the name which should be used for this API Management Standalone Gateway. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] resource_group_name: Specifies the name of the Resource Group where the API Management Standalone Gateway should exist. Changing this forces a new resource to be created.
        :param pulumi.Input['StandaloneGatewaySkuArgs'] sku: A `sku` block as defined below.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: A mapping of tags which should be assigned to the API Management Standalone Gateway. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] virtual_network_type: Specifies the type of VPN in which API Management gateway needs to be configured. Possible values are `External` and `Internal`. Changing this forces a new resource to be created.
        """
        if backend_subnet_id is not None:
            pulumi.set(__self__, "backend_subnet_id", backend_subnet_id)
        if location is not None:
            pulumi.set(__self__, "location", location)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if resource_group_name is not None:
            pulumi.set(__self__, "resource_group_name", resource_group_name)
        if sku is not None:
            pulumi.set(__self__, "sku", sku)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if virtual_network_type is not None:
            pulumi.set(__self__, "virtual_network_type", virtual_network_type)

    @_builtins.property
    @pulumi.getter(name="backendSubnetId")
    def backend_subnet_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the subnet ID in which the backend systems are hosted. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "backend_subnet_id")

    @backend_subnet_id.setter
    def backend_subnet_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "backend_subnet_id", value)

    @_builtins.property
    @pulumi.getter
    def location(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the Azure Region where the API Management Standalone Gateway should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @location.setter
    def location(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "location", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the name which should be used for this API Management Standalone Gateway. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the name of the Resource Group where the API Management Standalone Gateway should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "resource_group_name", value)

    @_builtins.property
    @pulumi.getter
    def sku(self) -> Optional[pulumi.Input['StandaloneGatewaySkuArgs']]:
        """
        A `sku` block as defined below.
        """
        return pulumi.get(self, "sku")

    @sku.setter
    def sku(self, value: Optional[pulumi.Input['StandaloneGatewaySkuArgs']]):
        pulumi.set(self, "sku", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        A mapping of tags which should be assigned to the API Management Standalone Gateway. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="virtualNetworkType")
    def virtual_network_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the type of VPN in which API Management gateway needs to be configured. Possible values are `External` and `Internal`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "virtual_network_type")

    @virtual_network_type.setter
    def virtual_network_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "virtual_network_type", value)


@pulumi.type_token("azure:apimanagement/standaloneGateway:StandaloneGateway")
class StandaloneGateway(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backend_subnet_id: Optional[pulumi.Input[_builtins.str]] = None,
                 location: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 sku: Optional[pulumi.Input[Union['StandaloneGatewaySkuArgs', 'StandaloneGatewaySkuArgsDict']]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 virtual_network_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages an Azure API Management Standalone Gateway.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_virtual_network = azure.network.VirtualNetwork("example",
            name="example-network",
            location=example.location,
            resource_group_name=example.name,
            address_spaces=["10.0.0.0/16"])
        example_subnet = azure.network.Subnet("example",
            name="example-subnet",
            resource_group_name=example.name,
            virtual_network_name=example_virtual_network.name,
            address_prefixes=["10.0.1.0/24"],
            delegations=[{
                "name": "apim-delegation",
                "service_delegation": {
                    "name": "Microsoft.Web/serverFarms",
                    "actions": ["Microsoft.Network/virtualNetworks/subnets/action"],
                },
            }])
        example_standalone_gateway = azure.apimanagement.StandaloneGateway("example",
            name="example-gateway-flexible",
            resource_group_name=example.name,
            location=example.location,
            virtual_network_type="External",
            backend_subnet_id=example_subnet.id,
            sku={
                "capacity": 1,
                "name": "WorkspaceGatewayPremium",
            },
            tags={
                "Hello": "World",
            })
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.ApiManagement` - 2024-05-01

        ## Import

        API Management Standalone Gateway can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:apimanagement/standaloneGateway:StandaloneGateway example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.ApiManagement/gateways/gateway1
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] backend_subnet_id: Specifies the subnet ID in which the backend systems are hosted. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] location: Specifies the Azure Region where the API Management Standalone Gateway should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] name: Specifies the name which should be used for this API Management Standalone Gateway. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] resource_group_name: Specifies the name of the Resource Group where the API Management Standalone Gateway should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[Union['StandaloneGatewaySkuArgs', 'StandaloneGatewaySkuArgsDict']] sku: A `sku` block as defined below.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: A mapping of tags which should be assigned to the API Management Standalone Gateway. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] virtual_network_type: Specifies the type of VPN in which API Management gateway needs to be configured. Possible values are `External` and `Internal`. Changing this forces a new resource to be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: StandaloneGatewayArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages an Azure API Management Standalone Gateway.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_virtual_network = azure.network.VirtualNetwork("example",
            name="example-network",
            location=example.location,
            resource_group_name=example.name,
            address_spaces=["10.0.0.0/16"])
        example_subnet = azure.network.Subnet("example",
            name="example-subnet",
            resource_group_name=example.name,
            virtual_network_name=example_virtual_network.name,
            address_prefixes=["10.0.1.0/24"],
            delegations=[{
                "name": "apim-delegation",
                "service_delegation": {
                    "name": "Microsoft.Web/serverFarms",
                    "actions": ["Microsoft.Network/virtualNetworks/subnets/action"],
                },
            }])
        example_standalone_gateway = azure.apimanagement.StandaloneGateway("example",
            name="example-gateway-flexible",
            resource_group_name=example.name,
            location=example.location,
            virtual_network_type="External",
            backend_subnet_id=example_subnet.id,
            sku={
                "capacity": 1,
                "name": "WorkspaceGatewayPremium",
            },
            tags={
                "Hello": "World",
            })
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.ApiManagement` - 2024-05-01

        ## Import

        API Management Standalone Gateway can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:apimanagement/standaloneGateway:StandaloneGateway example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.ApiManagement/gateways/gateway1
        ```


        :param str resource_name: The name of the resource.
        :param StandaloneGatewayArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(StandaloneGatewayArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 backend_subnet_id: Optional[pulumi.Input[_builtins.str]] = None,
                 location: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 sku: Optional[pulumi.Input[Union['StandaloneGatewaySkuArgs', 'StandaloneGatewaySkuArgsDict']]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 virtual_network_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = StandaloneGatewayArgs.__new__(StandaloneGatewayArgs)

            __props__.__dict__["backend_subnet_id"] = backend_subnet_id
            __props__.__dict__["location"] = location
            __props__.__dict__["name"] = name
            if resource_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__.__dict__["resource_group_name"] = resource_group_name
            if sku is None and not opts.urn:
                raise TypeError("Missing required property 'sku'")
            __props__.__dict__["sku"] = sku
            __props__.__dict__["tags"] = tags
            __props__.__dict__["virtual_network_type"] = virtual_network_type
        super(StandaloneGateway, __self__).__init__(
            'azure:apimanagement/standaloneGateway:StandaloneGateway',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            backend_subnet_id: Optional[pulumi.Input[_builtins.str]] = None,
            location: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
            sku: Optional[pulumi.Input[Union['StandaloneGatewaySkuArgs', 'StandaloneGatewaySkuArgsDict']]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
            virtual_network_type: Optional[pulumi.Input[_builtins.str]] = None) -> 'StandaloneGateway':
        """
        Get an existing StandaloneGateway resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] backend_subnet_id: Specifies the subnet ID in which the backend systems are hosted. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] location: Specifies the Azure Region where the API Management Standalone Gateway should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] name: Specifies the name which should be used for this API Management Standalone Gateway. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] resource_group_name: Specifies the name of the Resource Group where the API Management Standalone Gateway should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[Union['StandaloneGatewaySkuArgs', 'StandaloneGatewaySkuArgsDict']] sku: A `sku` block as defined below.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: A mapping of tags which should be assigned to the API Management Standalone Gateway. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] virtual_network_type: Specifies the type of VPN in which API Management gateway needs to be configured. Possible values are `External` and `Internal`. Changing this forces a new resource to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _StandaloneGatewayState.__new__(_StandaloneGatewayState)

        __props__.__dict__["backend_subnet_id"] = backend_subnet_id
        __props__.__dict__["location"] = location
        __props__.__dict__["name"] = name
        __props__.__dict__["resource_group_name"] = resource_group_name
        __props__.__dict__["sku"] = sku
        __props__.__dict__["tags"] = tags
        __props__.__dict__["virtual_network_type"] = virtual_network_type
        return StandaloneGateway(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="backendSubnetId")
    def backend_subnet_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the subnet ID in which the backend systems are hosted. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "backend_subnet_id")

    @_builtins.property
    @pulumi.getter
    def location(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies the Azure Region where the API Management Standalone Gateway should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "location")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies the name which should be used for this API Management Standalone Gateway. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies the name of the Resource Group where the API Management Standalone Gateway should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @_builtins.property
    @pulumi.getter
    def sku(self) -> pulumi.Output['outputs.StandaloneGatewaySku']:
        """
        A `sku` block as defined below.
        """
        return pulumi.get(self, "sku")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, _builtins.str]]]:
        """
        A mapping of tags which should be assigned to the API Management Standalone Gateway. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="virtualNetworkType")
    def virtual_network_type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Specifies the type of VPN in which API Management gateway needs to be configured. Possible values are `External` and `Internal`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "virtual_network_type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetAccountResult',
    'AwaitableGetAccountResult',
    'get_account',
    'get_account_output',
]

@pulumi.output_type
class GetAccountResult:
    """
    A collection of values returned by getAccount.
    """
    def __init__(__self__, custom_question_answering_search_service_id=None, custom_subdomain_name=None, customer_managed_keys=None, dynamic_throttling_enabled=None, endpoint=None, fqdns=None, id=None, identities=None, kind=None, local_auth_enabled=None, location=None, metrics_advisor_aad_client_id=None, metrics_advisor_aad_tenant_id=None, metrics_advisor_super_user_name=None, metrics_advisor_website_name=None, name=None, network_acls=None, network_injections=None, outbound_network_access_restricted=None, primary_access_key=None, project_management_enabled=None, public_network_access_enabled=None, qna_runtime_endpoint=None, resource_group_name=None, secondary_access_key=None, sku_name=None, storages=None, tags=None):
        if custom_question_answering_search_service_id and not isinstance(custom_question_answering_search_service_id, str):
            raise TypeError("Expected argument 'custom_question_answering_search_service_id' to be a str")
        pulumi.set(__self__, "custom_question_answering_search_service_id", custom_question_answering_search_service_id)
        if custom_subdomain_name and not isinstance(custom_subdomain_name, str):
            raise TypeError("Expected argument 'custom_subdomain_name' to be a str")
        pulumi.set(__self__, "custom_subdomain_name", custom_subdomain_name)
        if customer_managed_keys and not isinstance(customer_managed_keys, list):
            raise TypeError("Expected argument 'customer_managed_keys' to be a list")
        pulumi.set(__self__, "customer_managed_keys", customer_managed_keys)
        if dynamic_throttling_enabled and not isinstance(dynamic_throttling_enabled, bool):
            raise TypeError("Expected argument 'dynamic_throttling_enabled' to be a bool")
        pulumi.set(__self__, "dynamic_throttling_enabled", dynamic_throttling_enabled)
        if endpoint and not isinstance(endpoint, str):
            raise TypeError("Expected argument 'endpoint' to be a str")
        pulumi.set(__self__, "endpoint", endpoint)
        if fqdns and not isinstance(fqdns, list):
            raise TypeError("Expected argument 'fqdns' to be a list")
        pulumi.set(__self__, "fqdns", fqdns)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identities and not isinstance(identities, list):
            raise TypeError("Expected argument 'identities' to be a list")
        pulumi.set(__self__, "identities", identities)
        if kind and not isinstance(kind, str):
            raise TypeError("Expected argument 'kind' to be a str")
        pulumi.set(__self__, "kind", kind)
        if local_auth_enabled and not isinstance(local_auth_enabled, bool):
            raise TypeError("Expected argument 'local_auth_enabled' to be a bool")
        pulumi.set(__self__, "local_auth_enabled", local_auth_enabled)
        if location and not isinstance(location, str):
            raise TypeError("Expected argument 'location' to be a str")
        pulumi.set(__self__, "location", location)
        if metrics_advisor_aad_client_id and not isinstance(metrics_advisor_aad_client_id, str):
            raise TypeError("Expected argument 'metrics_advisor_aad_client_id' to be a str")
        pulumi.set(__self__, "metrics_advisor_aad_client_id", metrics_advisor_aad_client_id)
        if metrics_advisor_aad_tenant_id and not isinstance(metrics_advisor_aad_tenant_id, str):
            raise TypeError("Expected argument 'metrics_advisor_aad_tenant_id' to be a str")
        pulumi.set(__self__, "metrics_advisor_aad_tenant_id", metrics_advisor_aad_tenant_id)
        if metrics_advisor_super_user_name and not isinstance(metrics_advisor_super_user_name, str):
            raise TypeError("Expected argument 'metrics_advisor_super_user_name' to be a str")
        pulumi.set(__self__, "metrics_advisor_super_user_name", metrics_advisor_super_user_name)
        if metrics_advisor_website_name and not isinstance(metrics_advisor_website_name, str):
            raise TypeError("Expected argument 'metrics_advisor_website_name' to be a str")
        pulumi.set(__self__, "metrics_advisor_website_name", metrics_advisor_website_name)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if network_acls and not isinstance(network_acls, list):
            raise TypeError("Expected argument 'network_acls' to be a list")
        pulumi.set(__self__, "network_acls", network_acls)
        if network_injections and not isinstance(network_injections, list):
            raise TypeError("Expected argument 'network_injections' to be a list")
        pulumi.set(__self__, "network_injections", network_injections)
        if outbound_network_access_restricted and not isinstance(outbound_network_access_restricted, bool):
            raise TypeError("Expected argument 'outbound_network_access_restricted' to be a bool")
        pulumi.set(__self__, "outbound_network_access_restricted", outbound_network_access_restricted)
        if primary_access_key and not isinstance(primary_access_key, str):
            raise TypeError("Expected argument 'primary_access_key' to be a str")
        pulumi.set(__self__, "primary_access_key", primary_access_key)
        if project_management_enabled and not isinstance(project_management_enabled, bool):
            raise TypeError("Expected argument 'project_management_enabled' to be a bool")
        pulumi.set(__self__, "project_management_enabled", project_management_enabled)
        if public_network_access_enabled and not isinstance(public_network_access_enabled, bool):
            raise TypeError("Expected argument 'public_network_access_enabled' to be a bool")
        pulumi.set(__self__, "public_network_access_enabled", public_network_access_enabled)
        if qna_runtime_endpoint and not isinstance(qna_runtime_endpoint, str):
            raise TypeError("Expected argument 'qna_runtime_endpoint' to be a str")
        pulumi.set(__self__, "qna_runtime_endpoint", qna_runtime_endpoint)
        if resource_group_name and not isinstance(resource_group_name, str):
            raise TypeError("Expected argument 'resource_group_name' to be a str")
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        if secondary_access_key and not isinstance(secondary_access_key, str):
            raise TypeError("Expected argument 'secondary_access_key' to be a str")
        pulumi.set(__self__, "secondary_access_key", secondary_access_key)
        if sku_name and not isinstance(sku_name, str):
            raise TypeError("Expected argument 'sku_name' to be a str")
        pulumi.set(__self__, "sku_name", sku_name)
        if storages and not isinstance(storages, list):
            raise TypeError("Expected argument 'storages' to be a list")
        pulumi.set(__self__, "storages", storages)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="customQuestionAnsweringSearchServiceId")
    def custom_question_answering_search_service_id(self) -> _builtins.str:
        """
        The ID of the search service.
        """
        return pulumi.get(self, "custom_question_answering_search_service_id")

    @_builtins.property
    @pulumi.getter(name="customSubdomainName")
    def custom_subdomain_name(self) -> _builtins.str:
        """
        The subdomain name used for Entra ID token-based authentication.
        """
        return pulumi.get(self, "custom_subdomain_name")

    @_builtins.property
    @pulumi.getter(name="customerManagedKeys")
    def customer_managed_keys(self) -> Sequence['outputs.GetAccountCustomerManagedKeyResult']:
        """
        A `customer_managed_key` block as defined below.
        """
        return pulumi.get(self, "customer_managed_keys")

    @_builtins.property
    @pulumi.getter(name="dynamicThrottlingEnabled")
    def dynamic_throttling_enabled(self) -> _builtins.bool:
        """
        Whether dynamic throttling is enabled for this Cognitive Services Account.
        """
        return pulumi.get(self, "dynamic_throttling_enabled")

    @_builtins.property
    @pulumi.getter
    def endpoint(self) -> _builtins.str:
        """
        The endpoint of the Cognitive Services Account.
        """
        return pulumi.get(self, "endpoint")

    @_builtins.property
    @pulumi.getter
    def fqdns(self) -> Sequence[_builtins.str]:
        """
        List of FQDNs allowed for the Cognitive Services Account.
        """
        return pulumi.get(self, "fqdns")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identities(self) -> Sequence['outputs.GetAccountIdentityResult']:
        """
        A `identity` block as defined below.
        """
        return pulumi.get(self, "identities")

    @_builtins.property
    @pulumi.getter
    def kind(self) -> _builtins.str:
        """
        The type of the Cognitive Services Account.
        """
        return pulumi.get(self, "kind")

    @_builtins.property
    @pulumi.getter(name="localAuthEnabled")
    def local_auth_enabled(self) -> _builtins.bool:
        """
        Whether local authentication methods are enabled for the Cognitive Services Account.
        """
        return pulumi.get(self, "local_auth_enabled")

    @_builtins.property
    @pulumi.getter
    def location(self) -> _builtins.str:
        """
        The Azure location where the Cognitive Services Account exists.
        """
        return pulumi.get(self, "location")

    @_builtins.property
    @pulumi.getter(name="metricsAdvisorAadClientId")
    def metrics_advisor_aad_client_id(self) -> _builtins.str:
        """
        The Microsoft Entra Application (client) ID.
        """
        return pulumi.get(self, "metrics_advisor_aad_client_id")

    @_builtins.property
    @pulumi.getter(name="metricsAdvisorAadTenantId")
    def metrics_advisor_aad_tenant_id(self) -> _builtins.str:
        """
        The Microsoft Entra Tenant ID.
        """
        return pulumi.get(self, "metrics_advisor_aad_tenant_id")

    @_builtins.property
    @pulumi.getter(name="metricsAdvisorSuperUserName")
    def metrics_advisor_super_user_name(self) -> _builtins.str:
        """
        The super user of Metrics Advisor.
        """
        return pulumi.get(self, "metrics_advisor_super_user_name")

    @_builtins.property
    @pulumi.getter(name="metricsAdvisorWebsiteName")
    def metrics_advisor_website_name(self) -> _builtins.str:
        """
        The website name of Metrics Advisor.
        """
        return pulumi.get(self, "metrics_advisor_website_name")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="networkAcls")
    def network_acls(self) -> Sequence['outputs.GetAccountNetworkAclResult']:
        """
        A `network_acls` block as defined below.
        """
        return pulumi.get(self, "network_acls")

    @_builtins.property
    @pulumi.getter(name="networkInjections")
    def network_injections(self) -> Sequence['outputs.GetAccountNetworkInjectionResult']:
        """
        A `network_injection` block as defined below.
        """
        return pulumi.get(self, "network_injections")

    @_builtins.property
    @pulumi.getter(name="outboundNetworkAccessRestricted")
    def outbound_network_access_restricted(self) -> _builtins.bool:
        """
        Whether outbound network access is restricted for the Cognitive Services Account.
        """
        return pulumi.get(self, "outbound_network_access_restricted")

    @_builtins.property
    @pulumi.getter(name="primaryAccessKey")
    def primary_access_key(self) -> _builtins.str:
        """
        The primary access key of the Cognitive Services Account.
        """
        return pulumi.get(self, "primary_access_key")

    @_builtins.property
    @pulumi.getter(name="projectManagementEnabled")
    def project_management_enabled(self) -> _builtins.bool:
        """
        Whether project management is enabled.
        """
        return pulumi.get(self, "project_management_enabled")

    @_builtins.property
    @pulumi.getter(name="publicNetworkAccessEnabled")
    def public_network_access_enabled(self) -> _builtins.bool:
        """
        Whether public network access is allowed for the Cognitive Services Account.
        """
        return pulumi.get(self, "public_network_access_enabled")

    @_builtins.property
    @pulumi.getter(name="qnaRuntimeEndpoint")
    def qna_runtime_endpoint(self) -> _builtins.str:
        """
        The link to the QNA runtime.
        """
        return pulumi.get(self, "qna_runtime_endpoint")

    @_builtins.property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> _builtins.str:
        return pulumi.get(self, "resource_group_name")

    @_builtins.property
    @pulumi.getter(name="secondaryAccessKey")
    def secondary_access_key(self) -> _builtins.str:
        """
        The secondary access key of the Cognitive Services Account.
        """
        return pulumi.get(self, "secondary_access_key")

    @_builtins.property
    @pulumi.getter(name="skuName")
    def sku_name(self) -> _builtins.str:
        """
        The SKU name of the Cognitive Services Account.
        """
        return pulumi.get(self, "sku_name")

    @_builtins.property
    @pulumi.getter
    def storages(self) -> Sequence['outputs.GetAccountStorageResult']:
        """
        A `storage` block as defined below.
        """
        return pulumi.get(self, "storages")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, _builtins.str]]:
        """
        A mapping of tags to assigned to the resource.
        """
        return pulumi.get(self, "tags")


class AwaitableGetAccountResult(GetAccountResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAccountResult(
            custom_question_answering_search_service_id=self.custom_question_answering_search_service_id,
            custom_subdomain_name=self.custom_subdomain_name,
            customer_managed_keys=self.customer_managed_keys,
            dynamic_throttling_enabled=self.dynamic_throttling_enabled,
            endpoint=self.endpoint,
            fqdns=self.fqdns,
            id=self.id,
            identities=self.identities,
            kind=self.kind,
            local_auth_enabled=self.local_auth_enabled,
            location=self.location,
            metrics_advisor_aad_client_id=self.metrics_advisor_aad_client_id,
            metrics_advisor_aad_tenant_id=self.metrics_advisor_aad_tenant_id,
            metrics_advisor_super_user_name=self.metrics_advisor_super_user_name,
            metrics_advisor_website_name=self.metrics_advisor_website_name,
            name=self.name,
            network_acls=self.network_acls,
            network_injections=self.network_injections,
            outbound_network_access_restricted=self.outbound_network_access_restricted,
            primary_access_key=self.primary_access_key,
            project_management_enabled=self.project_management_enabled,
            public_network_access_enabled=self.public_network_access_enabled,
            qna_runtime_endpoint=self.qna_runtime_endpoint,
            resource_group_name=self.resource_group_name,
            secondary_access_key=self.secondary_access_key,
            sku_name=self.sku_name,
            storages=self.storages,
            tags=self.tags)


def get_account(name: Optional[_builtins.str] = None,
                resource_group_name: Optional[_builtins.str] = None,
                tags: Optional[Mapping[str, _builtins.str]] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAccountResult:
    """
    Use this data source to access information about an existing Cognitive Services Account.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    test = azure.cognitive.get_account(name="example-account",
        resource_group_name="cognitive_account_rg")
    pulumi.export("primaryAccessKey", test.primary_access_key)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Microsoft.CognitiveServices` - 2025-06-01


    :param _builtins.str name: Specifies the name of the Cognitive Services Account.
    :param _builtins.str resource_group_name: Specifies the name of the resource group where the Cognitive Services Account resides.
    :param Mapping[str, _builtins.str] tags: A mapping of tags to assigned to the resource.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:cognitive/getAccount:getAccount', __args__, opts=opts, typ=GetAccountResult).value

    return AwaitableGetAccountResult(
        custom_question_answering_search_service_id=pulumi.get(__ret__, 'custom_question_answering_search_service_id'),
        custom_subdomain_name=pulumi.get(__ret__, 'custom_subdomain_name'),
        customer_managed_keys=pulumi.get(__ret__, 'customer_managed_keys'),
        dynamic_throttling_enabled=pulumi.get(__ret__, 'dynamic_throttling_enabled'),
        endpoint=pulumi.get(__ret__, 'endpoint'),
        fqdns=pulumi.get(__ret__, 'fqdns'),
        id=pulumi.get(__ret__, 'id'),
        identities=pulumi.get(__ret__, 'identities'),
        kind=pulumi.get(__ret__, 'kind'),
        local_auth_enabled=pulumi.get(__ret__, 'local_auth_enabled'),
        location=pulumi.get(__ret__, 'location'),
        metrics_advisor_aad_client_id=pulumi.get(__ret__, 'metrics_advisor_aad_client_id'),
        metrics_advisor_aad_tenant_id=pulumi.get(__ret__, 'metrics_advisor_aad_tenant_id'),
        metrics_advisor_super_user_name=pulumi.get(__ret__, 'metrics_advisor_super_user_name'),
        metrics_advisor_website_name=pulumi.get(__ret__, 'metrics_advisor_website_name'),
        name=pulumi.get(__ret__, 'name'),
        network_acls=pulumi.get(__ret__, 'network_acls'),
        network_injections=pulumi.get(__ret__, 'network_injections'),
        outbound_network_access_restricted=pulumi.get(__ret__, 'outbound_network_access_restricted'),
        primary_access_key=pulumi.get(__ret__, 'primary_access_key'),
        project_management_enabled=pulumi.get(__ret__, 'project_management_enabled'),
        public_network_access_enabled=pulumi.get(__ret__, 'public_network_access_enabled'),
        qna_runtime_endpoint=pulumi.get(__ret__, 'qna_runtime_endpoint'),
        resource_group_name=pulumi.get(__ret__, 'resource_group_name'),
        secondary_access_key=pulumi.get(__ret__, 'secondary_access_key'),
        sku_name=pulumi.get(__ret__, 'sku_name'),
        storages=pulumi.get(__ret__, 'storages'),
        tags=pulumi.get(__ret__, 'tags'))
def get_account_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                       resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                       tags: Optional[pulumi.Input[Optional[Mapping[str, _builtins.str]]]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAccountResult]:
    """
    Use this data source to access information about an existing Cognitive Services Account.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    test = azure.cognitive.get_account(name="example-account",
        resource_group_name="cognitive_account_rg")
    pulumi.export("primaryAccessKey", test.primary_access_key)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Microsoft.CognitiveServices` - 2025-06-01


    :param _builtins.str name: Specifies the name of the Cognitive Services Account.
    :param _builtins.str resource_group_name: Specifies the name of the resource group where the Cognitive Services Account resides.
    :param Mapping[str, _builtins.str] tags: A mapping of tags to assigned to the resource.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    __args__['tags'] = tags
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:cognitive/getAccount:getAccount', __args__, opts=opts, typ=GetAccountResult)
    return __ret__.apply(lambda __response__: GetAccountResult(
        custom_question_answering_search_service_id=pulumi.get(__response__, 'custom_question_answering_search_service_id'),
        custom_subdomain_name=pulumi.get(__response__, 'custom_subdomain_name'),
        customer_managed_keys=pulumi.get(__response__, 'customer_managed_keys'),
        dynamic_throttling_enabled=pulumi.get(__response__, 'dynamic_throttling_enabled'),
        endpoint=pulumi.get(__response__, 'endpoint'),
        fqdns=pulumi.get(__response__, 'fqdns'),
        id=pulumi.get(__response__, 'id'),
        identities=pulumi.get(__response__, 'identities'),
        kind=pulumi.get(__response__, 'kind'),
        local_auth_enabled=pulumi.get(__response__, 'local_auth_enabled'),
        location=pulumi.get(__response__, 'location'),
        metrics_advisor_aad_client_id=pulumi.get(__response__, 'metrics_advisor_aad_client_id'),
        metrics_advisor_aad_tenant_id=pulumi.get(__response__, 'metrics_advisor_aad_tenant_id'),
        metrics_advisor_super_user_name=pulumi.get(__response__, 'metrics_advisor_super_user_name'),
        metrics_advisor_website_name=pulumi.get(__response__, 'metrics_advisor_website_name'),
        name=pulumi.get(__response__, 'name'),
        network_acls=pulumi.get(__response__, 'network_acls'),
        network_injections=pulumi.get(__response__, 'network_injections'),
        outbound_network_access_restricted=pulumi.get(__response__, 'outbound_network_access_restricted'),
        primary_access_key=pulumi.get(__response__, 'primary_access_key'),
        project_management_enabled=pulumi.get(__response__, 'project_management_enabled'),
        public_network_access_enabled=pulumi.get(__response__, 'public_network_access_enabled'),
        qna_runtime_endpoint=pulumi.get(__response__, 'qna_runtime_endpoint'),
        resource_group_name=pulumi.get(__response__, 'resource_group_name'),
        secondary_access_key=pulumi.get(__response__, 'secondary_access_key'),
        sku_name=pulumi.get(__response__, 'sku_name'),
        storages=pulumi.get(__response__, 'storages'),
        tags=pulumi.get(__response__, 'tags')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .account import *
from .account_customer_managed_key import *
from .account_project import *
from .account_rai_blocklist import *
from .account_rai_policy import *
from .ai_services import *
from .deployment import *
from .get_account import *
from .get_account_project import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ApiKeyArgs', 'ApiKey']

@pulumi.input_type
class ApiKeyArgs:
    def __init__(__self__, *,
                 end_date_time: pulumi.Input[_builtins.str],
                 nginx_deployment_id: pulumi.Input[_builtins.str],
                 secret_text: pulumi.Input[_builtins.str],
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a ApiKey resource.

        :param pulumi.Input[_builtins.str] end_date_time: The RFC3339 formatted date-time after which this Dataplane API Key is no longer valid. The maximum value is now+2y.
        :param pulumi.Input[_builtins.str] nginx_deployment_id: The ID of the NGINX Deployment that the API key is associated with. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] secret_text: The value used as the Dataplane API Key. The API key requirements can be found in the [NGINXaaS Documentation](https://docs.nginx.com/nginxaas/azure/quickstart/loadbalancer-kubernetes/#create-an-nginxaas-data-plane-api-key).
        :param pulumi.Input[_builtins.str] name: The name of the NGINX Dataplane API Key. Changing this forces a new resource to be created.
        """
        pulumi.set(__self__, "end_date_time", end_date_time)
        pulumi.set(__self__, "nginx_deployment_id", nginx_deployment_id)
        pulumi.set(__self__, "secret_text", secret_text)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="endDateTime")
    def end_date_time(self) -> pulumi.Input[_builtins.str]:
        """
        The RFC3339 formatted date-time after which this Dataplane API Key is no longer valid. The maximum value is now+2y.
        """
        return pulumi.get(self, "end_date_time")

    @end_date_time.setter
    def end_date_time(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "end_date_time", value)

    @_builtins.property
    @pulumi.getter(name="nginxDeploymentId")
    def nginx_deployment_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the NGINX Deployment that the API key is associated with. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "nginx_deployment_id")

    @nginx_deployment_id.setter
    def nginx_deployment_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "nginx_deployment_id", value)

    @_builtins.property
    @pulumi.getter(name="secretText")
    def secret_text(self) -> pulumi.Input[_builtins.str]:
        """
        The value used as the Dataplane API Key. The API key requirements can be found in the [NGINXaaS Documentation](https://docs.nginx.com/nginxaas/azure/quickstart/loadbalancer-kubernetes/#create-an-nginxaas-data-plane-api-key).
        """
        return pulumi.get(self, "secret_text")

    @secret_text.setter
    def secret_text(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "secret_text", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the NGINX Dataplane API Key. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _ApiKeyState:
    def __init__(__self__, *,
                 end_date_time: Optional[pulumi.Input[_builtins.str]] = None,
                 hint: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 nginx_deployment_id: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_text: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ApiKey resources.

        :param pulumi.Input[_builtins.str] end_date_time: The RFC3339 formatted date-time after which this Dataplane API Key is no longer valid. The maximum value is now+2y.
        :param pulumi.Input[_builtins.str] hint: The first three characters of the secret text to help identify it in use.
        :param pulumi.Input[_builtins.str] name: The name of the NGINX Dataplane API Key. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] nginx_deployment_id: The ID of the NGINX Deployment that the API key is associated with. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] secret_text: The value used as the Dataplane API Key. The API key requirements can be found in the [NGINXaaS Documentation](https://docs.nginx.com/nginxaas/azure/quickstart/loadbalancer-kubernetes/#create-an-nginxaas-data-plane-api-key).
        """
        if end_date_time is not None:
            pulumi.set(__self__, "end_date_time", end_date_time)
        if hint is not None:
            pulumi.set(__self__, "hint", hint)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if nginx_deployment_id is not None:
            pulumi.set(__self__, "nginx_deployment_id", nginx_deployment_id)
        if secret_text is not None:
            pulumi.set(__self__, "secret_text", secret_text)

    @_builtins.property
    @pulumi.getter(name="endDateTime")
    def end_date_time(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The RFC3339 formatted date-time after which this Dataplane API Key is no longer valid. The maximum value is now+2y.
        """
        return pulumi.get(self, "end_date_time")

    @end_date_time.setter
    def end_date_time(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "end_date_time", value)

    @_builtins.property
    @pulumi.getter
    def hint(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The first three characters of the secret text to help identify it in use.
        """
        return pulumi.get(self, "hint")

    @hint.setter
    def hint(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "hint", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the NGINX Dataplane API Key. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="nginxDeploymentId")
    def nginx_deployment_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the NGINX Deployment that the API key is associated with. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "nginx_deployment_id")

    @nginx_deployment_id.setter
    def nginx_deployment_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "nginx_deployment_id", value)

    @_builtins.property
    @pulumi.getter(name="secretText")
    def secret_text(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The value used as the Dataplane API Key. The API key requirements can be found in the [NGINXaaS Documentation](https://docs.nginx.com/nginxaas/azure/quickstart/loadbalancer-kubernetes/#create-an-nginxaas-data-plane-api-key).
        """
        return pulumi.get(self, "secret_text")

    @secret_text.setter
    def secret_text(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "secret_text", value)


@pulumi.type_token("azure:nginx/apiKey:ApiKey")
class ApiKey(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 end_date_time: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 nginx_deployment_id: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_text: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Manages the Dataplane API Key for an Nginx Deployment.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-rg",
            location="West Europe")
        example_public_ip = azure.network.PublicIp("example",
            name="example",
            resource_group_name=example.name,
            location=example.location,
            allocation_method="Static",
            sku="Standard",
            tags={
                "environment": "Production",
            })
        example_virtual_network = azure.network.VirtualNetwork("example",
            name="example-vnet",
            address_spaces=["10.0.0.0/16"],
            location=example.location,
            resource_group_name=example.name)
        example_subnet = azure.network.Subnet("example",
            name="example-subnet",
            resource_group_name=example.name,
            virtual_network_name=example_virtual_network.name,
            address_prefixes=["10.0.2.0/24"],
            delegations=[{
                "name": "delegation",
                "service_delegation": {
                    "name": "NGINX.NGINXPLUS/nginxDeployments",
                    "actions": ["Microsoft.Network/virtualNetworks/subnets/join/action"],
                },
            }])
        example_deployment = azure.nginx.Deployment("example",
            name="example-nginx",
            resource_group_name=example.name,
            sku="standardv3_Monthly",
            location=example.location,
            automatic_upgrade_channel="stable",
            frontend_public={
                "ip_addresses": [example_public_ip.id],
            },
            network_interfaces=[{
                "subnet_id": example_subnet.id,
            }],
            capacity=20,
            email="user@test.com")
        example_api_key = azure.nginx.ApiKey("example",
            name="example-api-key",
            nginx_deployment_id=example_deployment.id,
            secret_text="727c8642-6807-4254-9d02-ae93bfad21de",
            end_date_time="2027-01-01T00:00:00Z")
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Nginx.NginxPlus` - 2024-11-01-preview

        ## Import

        An NGINX Dataplane API Key can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:nginx/apiKey:ApiKey example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Nginx.NginxPlus/nginxDeployments/deploy1/apiKeys/key1
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] end_date_time: The RFC3339 formatted date-time after which this Dataplane API Key is no longer valid. The maximum value is now+2y.
        :param pulumi.Input[_builtins.str] name: The name of the NGINX Dataplane API Key. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] nginx_deployment_id: The ID of the NGINX Deployment that the API key is associated with. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] secret_text: The value used as the Dataplane API Key. The API key requirements can be found in the [NGINXaaS Documentation](https://docs.nginx.com/nginxaas/azure/quickstart/loadbalancer-kubernetes/#create-an-nginxaas-data-plane-api-key).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ApiKeyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages the Dataplane API Key for an Nginx Deployment.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-rg",
            location="West Europe")
        example_public_ip = azure.network.PublicIp("example",
            name="example",
            resource_group_name=example.name,
            location=example.location,
            allocation_method="Static",
            sku="Standard",
            tags={
                "environment": "Production",
            })
        example_virtual_network = azure.network.VirtualNetwork("example",
            name="example-vnet",
            address_spaces=["10.0.0.0/16"],
            location=example.location,
            resource_group_name=example.name)
        example_subnet = azure.network.Subnet("example",
            name="example-subnet",
            resource_group_name=example.name,
            virtual_network_name=example_virtual_network.name,
            address_prefixes=["10.0.2.0/24"],
            delegations=[{
                "name": "delegation",
                "service_delegation": {
                    "name": "NGINX.NGINXPLUS/nginxDeployments",
                    "actions": ["Microsoft.Network/virtualNetworks/subnets/join/action"],
                },
            }])
        example_deployment = azure.nginx.Deployment("example",
            name="example-nginx",
            resource_group_name=example.name,
            sku="standardv3_Monthly",
            location=example.location,
            automatic_upgrade_channel="stable",
            frontend_public={
                "ip_addresses": [example_public_ip.id],
            },
            network_interfaces=[{
                "subnet_id": example_subnet.id,
            }],
            capacity=20,
            email="user@test.com")
        example_api_key = azure.nginx.ApiKey("example",
            name="example-api-key",
            nginx_deployment_id=example_deployment.id,
            secret_text="727c8642-6807-4254-9d02-ae93bfad21de",
            end_date_time="2027-01-01T00:00:00Z")
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Nginx.NginxPlus` - 2024-11-01-preview

        ## Import

        An NGINX Dataplane API Key can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:nginx/apiKey:ApiKey example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Nginx.NginxPlus/nginxDeployments/deploy1/apiKeys/key1
        ```


        :param str resource_name: The name of the resource.
        :param ApiKeyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ApiKeyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 end_date_time: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 nginx_deployment_id: Optional[pulumi.Input[_builtins.str]] = None,
                 secret_text: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ApiKeyArgs.__new__(ApiKeyArgs)

            if end_date_time is None and not opts.urn:
                raise TypeError("Missing required property 'end_date_time'")
            __props__.__dict__["end_date_time"] = end_date_time
            __props__.__dict__["name"] = name
            if nginx_deployment_id is None and not opts.urn:
                raise TypeError("Missing required property 'nginx_deployment_id'")
            __props__.__dict__["nginx_deployment_id"] = nginx_deployment_id
            if secret_text is None and not opts.urn:
                raise TypeError("Missing required property 'secret_text'")
            __props__.__dict__["secret_text"] = None if secret_text is None else pulumi.Output.secret(secret_text)
            __props__.__dict__["hint"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["secretText"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(ApiKey, __self__).__init__(
            'azure:nginx/apiKey:ApiKey',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            end_date_time: Optional[pulumi.Input[_builtins.str]] = None,
            hint: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            nginx_deployment_id: Optional[pulumi.Input[_builtins.str]] = None,
            secret_text: Optional[pulumi.Input[_builtins.str]] = None) -> 'ApiKey':
        """
        Get an existing ApiKey resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] end_date_time: The RFC3339 formatted date-time after which this Dataplane API Key is no longer valid. The maximum value is now+2y.
        :param pulumi.Input[_builtins.str] hint: The first three characters of the secret text to help identify it in use.
        :param pulumi.Input[_builtins.str] name: The name of the NGINX Dataplane API Key. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] nginx_deployment_id: The ID of the NGINX Deployment that the API key is associated with. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] secret_text: The value used as the Dataplane API Key. The API key requirements can be found in the [NGINXaaS Documentation](https://docs.nginx.com/nginxaas/azure/quickstart/loadbalancer-kubernetes/#create-an-nginxaas-data-plane-api-key).
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ApiKeyState.__new__(_ApiKeyState)

        __props__.__dict__["end_date_time"] = end_date_time
        __props__.__dict__["hint"] = hint
        __props__.__dict__["name"] = name
        __props__.__dict__["nginx_deployment_id"] = nginx_deployment_id
        __props__.__dict__["secret_text"] = secret_text
        return ApiKey(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="endDateTime")
    def end_date_time(self) -> pulumi.Output[_builtins.str]:
        """
        The RFC3339 formatted date-time after which this Dataplane API Key is no longer valid. The maximum value is now+2y.
        """
        return pulumi.get(self, "end_date_time")

    @_builtins.property
    @pulumi.getter
    def hint(self) -> pulumi.Output[_builtins.str]:
        """
        The first three characters of the secret text to help identify it in use.
        """
        return pulumi.get(self, "hint")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the NGINX Dataplane API Key. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="nginxDeploymentId")
    def nginx_deployment_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the NGINX Deployment that the API key is associated with. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "nginx_deployment_id")

    @_builtins.property
    @pulumi.getter(name="secretText")
    def secret_text(self) -> pulumi.Output[_builtins.str]:
        """
        The value used as the Dataplane API Key. The API key requirements can be found in the [NGINXaaS Documentation](https://docs.nginx.com/nginxaas/azure/quickstart/loadbalancer-kubernetes/#create-an-nginxaas-data-plane-api-key).
        """
        return pulumi.get(self, "secret_text")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetDevBoxDefinitionResult',
    'AwaitableGetDevBoxDefinitionResult',
    'get_dev_box_definition',
    'get_dev_box_definition_output',
]

@pulumi.output_type
class GetDevBoxDefinitionResult:
    """
    A collection of values returned by getDevBoxDefinition.
    """
    def __init__(__self__, dev_center_id=None, hibernate_support_enabled=None, id=None, image_reference_id=None, location=None, name=None, sku_name=None, tags=None):
        if dev_center_id and not isinstance(dev_center_id, str):
            raise TypeError("Expected argument 'dev_center_id' to be a str")
        pulumi.set(__self__, "dev_center_id", dev_center_id)
        if hibernate_support_enabled and not isinstance(hibernate_support_enabled, bool):
            raise TypeError("Expected argument 'hibernate_support_enabled' to be a bool")
        pulumi.set(__self__, "hibernate_support_enabled", hibernate_support_enabled)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if image_reference_id and not isinstance(image_reference_id, str):
            raise TypeError("Expected argument 'image_reference_id' to be a str")
        pulumi.set(__self__, "image_reference_id", image_reference_id)
        if location and not isinstance(location, str):
            raise TypeError("Expected argument 'location' to be a str")
        pulumi.set(__self__, "location", location)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if sku_name and not isinstance(sku_name, str):
            raise TypeError("Expected argument 'sku_name' to be a str")
        pulumi.set(__self__, "sku_name", sku_name)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="devCenterId")
    def dev_center_id(self) -> _builtins.str:
        return pulumi.get(self, "dev_center_id")

    @_builtins.property
    @pulumi.getter(name="hibernateSupportEnabled")
    def hibernate_support_enabled(self) -> _builtins.bool:
        """
        Whether Dev Boxes created with this definition are capable of hibernation.
        """
        return pulumi.get(self, "hibernate_support_enabled")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="imageReferenceId")
    def image_reference_id(self) -> _builtins.str:
        """
        The ID of the image for the Dev Center Dev Box Definition.
        """
        return pulumi.get(self, "image_reference_id")

    @_builtins.property
    @pulumi.getter
    def location(self) -> _builtins.str:
        """
        The Azure Region where the Dev Center Dev Box Definition exists.
        """
        return pulumi.get(self, "location")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="skuName")
    def sku_name(self) -> _builtins.str:
        """
        The name of the SKU for the Dev Center Dev Box Definition.
        """
        return pulumi.get(self, "sku_name")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Mapping[str, _builtins.str]:
        """
        A mapping of tags assigned to the Dev Center Dev Box Definition.
        """
        return pulumi.get(self, "tags")


class AwaitableGetDevBoxDefinitionResult(GetDevBoxDefinitionResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDevBoxDefinitionResult(
            dev_center_id=self.dev_center_id,
            hibernate_support_enabled=self.hibernate_support_enabled,
            id=self.id,
            image_reference_id=self.image_reference_id,
            location=self.location,
            name=self.name,
            sku_name=self.sku_name,
            tags=self.tags)


def get_dev_box_definition(dev_center_id: Optional[_builtins.str] = None,
                           name: Optional[_builtins.str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDevBoxDefinitionResult:
    """
    Use this data source to access information about an existing Dev Center Dev Box Definition.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.devcenter.get_dev_box_definition(name=example_azurerm_dev_center_dev_box_definition["name"],
        dev_center_id=example_azurerm_dev_center_dev_box_definition["devCenterId"])
    pulumi.export("id", example.id)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Microsoft.DevCenter` - 2025-02-01


    :param _builtins.str dev_center_id: The ID of the associated Dev Center.
    :param _builtins.str name: The name of this Dev Center Dev Box Definition.
    """
    __args__ = dict()
    __args__['devCenterId'] = dev_center_id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:devcenter/getDevBoxDefinition:getDevBoxDefinition', __args__, opts=opts, typ=GetDevBoxDefinitionResult).value

    return AwaitableGetDevBoxDefinitionResult(
        dev_center_id=pulumi.get(__ret__, 'dev_center_id'),
        hibernate_support_enabled=pulumi.get(__ret__, 'hibernate_support_enabled'),
        id=pulumi.get(__ret__, 'id'),
        image_reference_id=pulumi.get(__ret__, 'image_reference_id'),
        location=pulumi.get(__ret__, 'location'),
        name=pulumi.get(__ret__, 'name'),
        sku_name=pulumi.get(__ret__, 'sku_name'),
        tags=pulumi.get(__ret__, 'tags'))
def get_dev_box_definition_output(dev_center_id: Optional[pulumi.Input[_builtins.str]] = None,
                                  name: Optional[pulumi.Input[_builtins.str]] = None,
                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDevBoxDefinitionResult]:
    """
    Use this data source to access information about an existing Dev Center Dev Box Definition.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.devcenter.get_dev_box_definition(name=example_azurerm_dev_center_dev_box_definition["name"],
        dev_center_id=example_azurerm_dev_center_dev_box_definition["devCenterId"])
    pulumi.export("id", example.id)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Microsoft.DevCenter` - 2025-02-01


    :param _builtins.str dev_center_id: The ID of the associated Dev Center.
    :param _builtins.str name: The name of this Dev Center Dev Box Definition.
    """
    __args__ = dict()
    __args__['devCenterId'] = dev_center_id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:devcenter/getDevBoxDefinition:getDevBoxDefinition', __args__, opts=opts, typ=GetDevBoxDefinitionResult)
    return __ret__.apply(lambda __response__: GetDevBoxDefinitionResult(
        dev_center_id=pulumi.get(__response__, 'dev_center_id'),
        hibernate_support_enabled=pulumi.get(__response__, 'hibernate_support_enabled'),
        id=pulumi.get(__response__, 'id'),
        image_reference_id=pulumi.get(__response__, 'image_reference_id'),
        location=pulumi.get(__response__, 'location'),
        name=pulumi.get(__response__, 'name'),
        sku_name=pulumi.get(__response__, 'sku_name'),
        tags=pulumi.get(__response__, 'tags')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['FrontdoorProfileArgs', 'FrontdoorProfile']

@pulumi.input_type
class FrontdoorProfileArgs:
    def __init__(__self__, *,
                 resource_group_name: pulumi.Input[_builtins.str],
                 sku_name: pulumi.Input[_builtins.str],
                 identity: Optional[pulumi.Input['FrontdoorProfileIdentityArgs']] = None,
                 log_scrubbing_rules: Optional[pulumi.Input[Sequence[pulumi.Input['FrontdoorProfileLogScrubbingRuleArgs']]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 response_timeout_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a FrontdoorProfile resource.

        :param pulumi.Input[_builtins.str] resource_group_name: The name of the Resource Group where this Front Door Profile should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] sku_name: Specifies the SKU for this Front Door Profile. Possible values include `Standard_AzureFrontDoor` and `Premium_AzureFrontDoor`. Changing this forces a new resource to be created.
        :param pulumi.Input['FrontdoorProfileIdentityArgs'] identity: An `identity` block as defined below.
        :param pulumi.Input[Sequence[pulumi.Input['FrontdoorProfileLogScrubbingRuleArgs']]] log_scrubbing_rules: One or more `log_scrubbing_rule` blocks as defined below.
               
               > **Note:** When no `log_scrubbing_rule` blocks are defined, log scrubbing will be automatically `disabled`. When one or more `log_scrubbing_rule` blocks are present, log scrubbing will be `enabled`.
        :param pulumi.Input[_builtins.str] name: Specifies the name of the Front Door Profile. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.int] response_timeout_seconds: Specifies the maximum response timeout in seconds. Possible values are between `16` and `240` seconds (inclusive). Defaults to `120` seconds.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: Specifies a mapping of tags to assign to the resource.
        """
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        pulumi.set(__self__, "sku_name", sku_name)
        if identity is not None:
            pulumi.set(__self__, "identity", identity)
        if log_scrubbing_rules is not None:
            pulumi.set(__self__, "log_scrubbing_rules", log_scrubbing_rules)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if response_timeout_seconds is not None:
            pulumi.set(__self__, "response_timeout_seconds", response_timeout_seconds)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Input[_builtins.str]:
        """
        The name of the Resource Group where this Front Door Profile should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "resource_group_name", value)

    @_builtins.property
    @pulumi.getter(name="skuName")
    def sku_name(self) -> pulumi.Input[_builtins.str]:
        """
        Specifies the SKU for this Front Door Profile. Possible values include `Standard_AzureFrontDoor` and `Premium_AzureFrontDoor`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "sku_name")

    @sku_name.setter
    def sku_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "sku_name", value)

    @_builtins.property
    @pulumi.getter
    def identity(self) -> Optional[pulumi.Input['FrontdoorProfileIdentityArgs']]:
        """
        An `identity` block as defined below.
        """
        return pulumi.get(self, "identity")

    @identity.setter
    def identity(self, value: Optional[pulumi.Input['FrontdoorProfileIdentityArgs']]):
        pulumi.set(self, "identity", value)

    @_builtins.property
    @pulumi.getter(name="logScrubbingRules")
    def log_scrubbing_rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['FrontdoorProfileLogScrubbingRuleArgs']]]]:
        """
        One or more `log_scrubbing_rule` blocks as defined below.

        > **Note:** When no `log_scrubbing_rule` blocks are defined, log scrubbing will be automatically `disabled`. When one or more `log_scrubbing_rule` blocks are present, log scrubbing will be `enabled`.
        """
        return pulumi.get(self, "log_scrubbing_rules")

    @log_scrubbing_rules.setter
    def log_scrubbing_rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['FrontdoorProfileLogScrubbingRuleArgs']]]]):
        pulumi.set(self, "log_scrubbing_rules", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the name of the Front Door Profile. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="responseTimeoutSeconds")
    def response_timeout_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies the maximum response timeout in seconds. Possible values are between `16` and `240` seconds (inclusive). Defaults to `120` seconds.
        """
        return pulumi.get(self, "response_timeout_seconds")

    @response_timeout_seconds.setter
    def response_timeout_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "response_timeout_seconds", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        Specifies a mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _FrontdoorProfileState:
    def __init__(__self__, *,
                 identity: Optional[pulumi.Input['FrontdoorProfileIdentityArgs']] = None,
                 log_scrubbing_rules: Optional[pulumi.Input[Sequence[pulumi.Input['FrontdoorProfileLogScrubbingRuleArgs']]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_guid: Optional[pulumi.Input[_builtins.str]] = None,
                 response_timeout_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 sku_name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering FrontdoorProfile resources.

        :param pulumi.Input['FrontdoorProfileIdentityArgs'] identity: An `identity` block as defined below.
        :param pulumi.Input[Sequence[pulumi.Input['FrontdoorProfileLogScrubbingRuleArgs']]] log_scrubbing_rules: One or more `log_scrubbing_rule` blocks as defined below.
               
               > **Note:** When no `log_scrubbing_rule` blocks are defined, log scrubbing will be automatically `disabled`. When one or more `log_scrubbing_rule` blocks are present, log scrubbing will be `enabled`.
        :param pulumi.Input[_builtins.str] name: Specifies the name of the Front Door Profile. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] resource_group_name: The name of the Resource Group where this Front Door Profile should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] resource_guid: The UUID of this Front Door Profile which will be sent in the HTTP Header as the `X-Azure-FDID` attribute.
        :param pulumi.Input[_builtins.int] response_timeout_seconds: Specifies the maximum response timeout in seconds. Possible values are between `16` and `240` seconds (inclusive). Defaults to `120` seconds.
        :param pulumi.Input[_builtins.str] sku_name: Specifies the SKU for this Front Door Profile. Possible values include `Standard_AzureFrontDoor` and `Premium_AzureFrontDoor`. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: Specifies a mapping of tags to assign to the resource.
        """
        if identity is not None:
            pulumi.set(__self__, "identity", identity)
        if log_scrubbing_rules is not None:
            pulumi.set(__self__, "log_scrubbing_rules", log_scrubbing_rules)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if resource_group_name is not None:
            pulumi.set(__self__, "resource_group_name", resource_group_name)
        if resource_guid is not None:
            pulumi.set(__self__, "resource_guid", resource_guid)
        if response_timeout_seconds is not None:
            pulumi.set(__self__, "response_timeout_seconds", response_timeout_seconds)
        if sku_name is not None:
            pulumi.set(__self__, "sku_name", sku_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter
    def identity(self) -> Optional[pulumi.Input['FrontdoorProfileIdentityArgs']]:
        """
        An `identity` block as defined below.
        """
        return pulumi.get(self, "identity")

    @identity.setter
    def identity(self, value: Optional[pulumi.Input['FrontdoorProfileIdentityArgs']]):
        pulumi.set(self, "identity", value)

    @_builtins.property
    @pulumi.getter(name="logScrubbingRules")
    def log_scrubbing_rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['FrontdoorProfileLogScrubbingRuleArgs']]]]:
        """
        One or more `log_scrubbing_rule` blocks as defined below.

        > **Note:** When no `log_scrubbing_rule` blocks are defined, log scrubbing will be automatically `disabled`. When one or more `log_scrubbing_rule` blocks are present, log scrubbing will be `enabled`.
        """
        return pulumi.get(self, "log_scrubbing_rules")

    @log_scrubbing_rules.setter
    def log_scrubbing_rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['FrontdoorProfileLogScrubbingRuleArgs']]]]):
        pulumi.set(self, "log_scrubbing_rules", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the name of the Front Door Profile. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the Resource Group where this Front Door Profile should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "resource_group_name", value)

    @_builtins.property
    @pulumi.getter(name="resourceGuid")
    def resource_guid(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The UUID of this Front Door Profile which will be sent in the HTTP Header as the `X-Azure-FDID` attribute.
        """
        return pulumi.get(self, "resource_guid")

    @resource_guid.setter
    def resource_guid(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "resource_guid", value)

    @_builtins.property
    @pulumi.getter(name="responseTimeoutSeconds")
    def response_timeout_seconds(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Specifies the maximum response timeout in seconds. Possible values are between `16` and `240` seconds (inclusive). Defaults to `120` seconds.
        """
        return pulumi.get(self, "response_timeout_seconds")

    @response_timeout_seconds.setter
    def response_timeout_seconds(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "response_timeout_seconds", value)

    @_builtins.property
    @pulumi.getter(name="skuName")
    def sku_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Specifies the SKU for this Front Door Profile. Possible values include `Standard_AzureFrontDoor` and `Premium_AzureFrontDoor`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "sku_name")

    @sku_name.setter
    def sku_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "sku_name", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]:
        """
        Specifies a mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("azure:cdn/frontdoorProfile:FrontdoorProfile")
class FrontdoorProfile(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 identity: Optional[pulumi.Input[Union['FrontdoorProfileIdentityArgs', 'FrontdoorProfileIdentityArgsDict']]] = None,
                 log_scrubbing_rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['FrontdoorProfileLogScrubbingRuleArgs', 'FrontdoorProfileLogScrubbingRuleArgsDict']]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 response_timeout_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 sku_name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Manages a Front Door (standard/premium) Profile which contains a collection of endpoints and origin groups.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_user_assigned_identity = azure.authorization.UserAssignedIdentity("example",
            location=example.location,
            name="example-identity",
            resource_group_name=example.name)
        example_frontdoor_profile = azure.cdn.FrontdoorProfile("example",
            name="example-cdn-profile",
            resource_group_name=example.name,
            sku_name="Premium_AzureFrontDoor",
            response_timeout_seconds=120,
            identity={
                "type": "SystemAssigned, UserAssigned",
                "identity_ids": [example_user_assigned_identity.id],
            },
            log_scrubbing_rules=[{
                "match_variable": "RequestIPAddress",
            }],
            tags={
                "environment": "Production",
            })
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.Cdn` - 2024-02-01

        ## Import

        Front Door Profiles can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:cdn/frontdoorProfile:FrontdoorProfile example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/mygroup1/providers/Microsoft.Cdn/profiles/myprofile1
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['FrontdoorProfileIdentityArgs', 'FrontdoorProfileIdentityArgsDict']] identity: An `identity` block as defined below.
        :param pulumi.Input[Sequence[pulumi.Input[Union['FrontdoorProfileLogScrubbingRuleArgs', 'FrontdoorProfileLogScrubbingRuleArgsDict']]]] log_scrubbing_rules: One or more `log_scrubbing_rule` blocks as defined below.
               
               > **Note:** When no `log_scrubbing_rule` blocks are defined, log scrubbing will be automatically `disabled`. When one or more `log_scrubbing_rule` blocks are present, log scrubbing will be `enabled`.
        :param pulumi.Input[_builtins.str] name: Specifies the name of the Front Door Profile. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] resource_group_name: The name of the Resource Group where this Front Door Profile should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.int] response_timeout_seconds: Specifies the maximum response timeout in seconds. Possible values are between `16` and `240` seconds (inclusive). Defaults to `120` seconds.
        :param pulumi.Input[_builtins.str] sku_name: Specifies the SKU for this Front Door Profile. Possible values include `Standard_AzureFrontDoor` and `Premium_AzureFrontDoor`. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: Specifies a mapping of tags to assign to the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FrontdoorProfileArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Front Door (standard/premium) Profile which contains a collection of endpoints and origin groups.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example = azure.core.ResourceGroup("example",
            name="example-resources",
            location="West Europe")
        example_user_assigned_identity = azure.authorization.UserAssignedIdentity("example",
            location=example.location,
            name="example-identity",
            resource_group_name=example.name)
        example_frontdoor_profile = azure.cdn.FrontdoorProfile("example",
            name="example-cdn-profile",
            resource_group_name=example.name,
            sku_name="Premium_AzureFrontDoor",
            response_timeout_seconds=120,
            identity={
                "type": "SystemAssigned, UserAssigned",
                "identity_ids": [example_user_assigned_identity.id],
            },
            log_scrubbing_rules=[{
                "match_variable": "RequestIPAddress",
            }],
            tags={
                "environment": "Production",
            })
        ```

        ## API Providers

        <!-- This section is generated, changes will be overwritten -->
        This resource uses the following Azure API Providers:

        * `Microsoft.Cdn` - 2024-02-01

        ## Import

        Front Door Profiles can be imported using the `resource id`, e.g.

        ```sh
        $ pulumi import azure:cdn/frontdoorProfile:FrontdoorProfile example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/mygroup1/providers/Microsoft.Cdn/profiles/myprofile1
        ```


        :param str resource_name: The name of the resource.
        :param FrontdoorProfileArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FrontdoorProfileArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 identity: Optional[pulumi.Input[Union['FrontdoorProfileIdentityArgs', 'FrontdoorProfileIdentityArgsDict']]] = None,
                 log_scrubbing_rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['FrontdoorProfileLogScrubbingRuleArgs', 'FrontdoorProfileLogScrubbingRuleArgsDict']]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                 response_timeout_seconds: Optional[pulumi.Input[_builtins.int]] = None,
                 sku_name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FrontdoorProfileArgs.__new__(FrontdoorProfileArgs)

            __props__.__dict__["identity"] = identity
            __props__.__dict__["log_scrubbing_rules"] = log_scrubbing_rules
            __props__.__dict__["name"] = name
            if resource_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__.__dict__["resource_group_name"] = resource_group_name
            __props__.__dict__["response_timeout_seconds"] = response_timeout_seconds
            if sku_name is None and not opts.urn:
                raise TypeError("Missing required property 'sku_name'")
            __props__.__dict__["sku_name"] = sku_name
            __props__.__dict__["tags"] = tags
            __props__.__dict__["resource_guid"] = None
        super(FrontdoorProfile, __self__).__init__(
            'azure:cdn/frontdoorProfile:FrontdoorProfile',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            identity: Optional[pulumi.Input[Union['FrontdoorProfileIdentityArgs', 'FrontdoorProfileIdentityArgsDict']]] = None,
            log_scrubbing_rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['FrontdoorProfileLogScrubbingRuleArgs', 'FrontdoorProfileLogScrubbingRuleArgsDict']]]]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
            resource_guid: Optional[pulumi.Input[_builtins.str]] = None,
            response_timeout_seconds: Optional[pulumi.Input[_builtins.int]] = None,
            sku_name: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]]] = None) -> 'FrontdoorProfile':
        """
        Get an existing FrontdoorProfile resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['FrontdoorProfileIdentityArgs', 'FrontdoorProfileIdentityArgsDict']] identity: An `identity` block as defined below.
        :param pulumi.Input[Sequence[pulumi.Input[Union['FrontdoorProfileLogScrubbingRuleArgs', 'FrontdoorProfileLogScrubbingRuleArgsDict']]]] log_scrubbing_rules: One or more `log_scrubbing_rule` blocks as defined below.
               
               > **Note:** When no `log_scrubbing_rule` blocks are defined, log scrubbing will be automatically `disabled`. When one or more `log_scrubbing_rule` blocks are present, log scrubbing will be `enabled`.
        :param pulumi.Input[_builtins.str] name: Specifies the name of the Front Door Profile. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] resource_group_name: The name of the Resource Group where this Front Door Profile should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[_builtins.str] resource_guid: The UUID of this Front Door Profile which will be sent in the HTTP Header as the `X-Azure-FDID` attribute.
        :param pulumi.Input[_builtins.int] response_timeout_seconds: Specifies the maximum response timeout in seconds. Possible values are between `16` and `240` seconds (inclusive). Defaults to `120` seconds.
        :param pulumi.Input[_builtins.str] sku_name: Specifies the SKU for this Front Door Profile. Possible values include `Standard_AzureFrontDoor` and `Premium_AzureFrontDoor`. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[_builtins.str]]] tags: Specifies a mapping of tags to assign to the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FrontdoorProfileState.__new__(_FrontdoorProfileState)

        __props__.__dict__["identity"] = identity
        __props__.__dict__["log_scrubbing_rules"] = log_scrubbing_rules
        __props__.__dict__["name"] = name
        __props__.__dict__["resource_group_name"] = resource_group_name
        __props__.__dict__["resource_guid"] = resource_guid
        __props__.__dict__["response_timeout_seconds"] = response_timeout_seconds
        __props__.__dict__["sku_name"] = sku_name
        __props__.__dict__["tags"] = tags
        return FrontdoorProfile(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def identity(self) -> pulumi.Output[Optional['outputs.FrontdoorProfileIdentity']]:
        """
        An `identity` block as defined below.
        """
        return pulumi.get(self, "identity")

    @_builtins.property
    @pulumi.getter(name="logScrubbingRules")
    def log_scrubbing_rules(self) -> pulumi.Output[Optional[Sequence['outputs.FrontdoorProfileLogScrubbingRule']]]:
        """
        One or more `log_scrubbing_rule` blocks as defined below.

        > **Note:** When no `log_scrubbing_rule` blocks are defined, log scrubbing will be automatically `disabled`. When one or more `log_scrubbing_rule` blocks are present, log scrubbing will be `enabled`.
        """
        return pulumi.get(self, "log_scrubbing_rules")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies the name of the Front Door Profile. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the Resource Group where this Front Door Profile should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @_builtins.property
    @pulumi.getter(name="resourceGuid")
    def resource_guid(self) -> pulumi.Output[_builtins.str]:
        """
        The UUID of this Front Door Profile which will be sent in the HTTP Header as the `X-Azure-FDID` attribute.
        """
        return pulumi.get(self, "resource_guid")

    @_builtins.property
    @pulumi.getter(name="responseTimeoutSeconds")
    def response_timeout_seconds(self) -> pulumi.Output[Optional[_builtins.int]]:
        """
        Specifies the maximum response timeout in seconds. Possible values are between `16` and `240` seconds (inclusive). Defaults to `120` seconds.
        """
        return pulumi.get(self, "response_timeout_seconds")

    @_builtins.property
    @pulumi.getter(name="skuName")
    def sku_name(self) -> pulumi.Output[_builtins.str]:
        """
        Specifies the SKU for this Front Door Profile. Possible values include `Standard_AzureFrontDoor` and `Premium_AzureFrontDoor`. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "sku_name")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Mapping[str, _builtins.str]]]:
        """
        Specifies a mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetNetworkManagerIpamPoolResult',
    'AwaitableGetNetworkManagerIpamPoolResult',
    'get_network_manager_ipam_pool',
    'get_network_manager_ipam_pool_output',
]

@pulumi.output_type
class GetNetworkManagerIpamPoolResult:
    """
    A collection of values returned by getNetworkManagerIpamPool.
    """
    def __init__(__self__, address_prefixes=None, description=None, display_name=None, id=None, location=None, name=None, network_manager_id=None, parent_pool_name=None, tags=None):
        if address_prefixes and not isinstance(address_prefixes, list):
            raise TypeError("Expected argument 'address_prefixes' to be a list")
        pulumi.set(__self__, "address_prefixes", address_prefixes)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if location and not isinstance(location, str):
            raise TypeError("Expected argument 'location' to be a str")
        pulumi.set(__self__, "location", location)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if network_manager_id and not isinstance(network_manager_id, str):
            raise TypeError("Expected argument 'network_manager_id' to be a str")
        pulumi.set(__self__, "network_manager_id", network_manager_id)
        if parent_pool_name and not isinstance(parent_pool_name, str):
            raise TypeError("Expected argument 'parent_pool_name' to be a str")
        pulumi.set(__self__, "parent_pool_name", parent_pool_name)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter(name="addressPrefixes")
    def address_prefixes(self) -> Sequence[_builtins.str]:
        """
        A list of IPv4 or IPv6 IP address prefixes assigned to the Network Manager IPAM Pool.
        """
        return pulumi.get(self, "address_prefixes")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        The description of the Network Manager IPAM Pool.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> _builtins.str:
        """
        The display name of the Network Manager IPAM Pool.
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def location(self) -> _builtins.str:
        """
        The Azure Region where the Network Manager IPAM Pool exists.
        """
        return pulumi.get(self, "location")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="networkManagerId")
    def network_manager_id(self) -> _builtins.str:
        return pulumi.get(self, "network_manager_id")

    @_builtins.property
    @pulumi.getter(name="parentPoolName")
    def parent_pool_name(self) -> _builtins.str:
        """
        The name of the parent IPAM Pool.
        """
        return pulumi.get(self, "parent_pool_name")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Mapping[str, _builtins.str]:
        """
        A mapping of tags assigned to the Network Manager IPAM Pool.
        """
        return pulumi.get(self, "tags")


class AwaitableGetNetworkManagerIpamPoolResult(GetNetworkManagerIpamPoolResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNetworkManagerIpamPoolResult(
            address_prefixes=self.address_prefixes,
            description=self.description,
            display_name=self.display_name,
            id=self.id,
            location=self.location,
            name=self.name,
            network_manager_id=self.network_manager_id,
            parent_pool_name=self.parent_pool_name,
            tags=self.tags)


def get_network_manager_ipam_pool(name: Optional[_builtins.str] = None,
                                  network_manager_id: Optional[_builtins.str] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNetworkManagerIpamPoolResult:
    """
    Use this data source to access information about an existing Network Manager IPAM Pool.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example_resource_group = azure.core.ResourceGroup("example",
        name="example-resources",
        location="West Europe")
    current = azure.core.get_subscription()
    example_network_manager = azure.network.NetworkManager("example",
        name="example-network-manager",
        location=example_resource_group.location,
        resource_group_name=example_resource_group.name,
        scope={
            "subscription_ids": [current.id],
        })
    example_network_manager_ipam_pool = azure.network.NetworkManagerIpamPool("example",
        name="example-ipam-pool",
        location="West Europe",
        network_manager_id=example_network_manager.id,
        display_name="example-pool",
        address_prefixes=["10.0.0.0/24"])
    example = azure.network.get_network_manager_ipam_pool_output(name=example_network_manager_ipam_pool.name,
        network_manager_id=example_network_manager.id)
    pulumi.export("id", example.id)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Microsoft.Network` - 2025-01-01


    :param _builtins.str name: The name of this Network Manager IPAM Pool.
    :param _builtins.str network_manager_id: The ID of the parent Network Manager.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['networkManagerId'] = network_manager_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:network/getNetworkManagerIpamPool:getNetworkManagerIpamPool', __args__, opts=opts, typ=GetNetworkManagerIpamPoolResult).value

    return AwaitableGetNetworkManagerIpamPoolResult(
        address_prefixes=pulumi.get(__ret__, 'address_prefixes'),
        description=pulumi.get(__ret__, 'description'),
        display_name=pulumi.get(__ret__, 'display_name'),
        id=pulumi.get(__ret__, 'id'),
        location=pulumi.get(__ret__, 'location'),
        name=pulumi.get(__ret__, 'name'),
        network_manager_id=pulumi.get(__ret__, 'network_manager_id'),
        parent_pool_name=pulumi.get(__ret__, 'parent_pool_name'),
        tags=pulumi.get(__ret__, 'tags'))
def get_network_manager_ipam_pool_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                                         network_manager_id: Optional[pulumi.Input[_builtins.str]] = None,
                                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetNetworkManagerIpamPoolResult]:
    """
    Use this data source to access information about an existing Network Manager IPAM Pool.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example_resource_group = azure.core.ResourceGroup("example",
        name="example-resources",
        location="West Europe")
    current = azure.core.get_subscription()
    example_network_manager = azure.network.NetworkManager("example",
        name="example-network-manager",
        location=example_resource_group.location,
        resource_group_name=example_resource_group.name,
        scope={
            "subscription_ids": [current.id],
        })
    example_network_manager_ipam_pool = azure.network.NetworkManagerIpamPool("example",
        name="example-ipam-pool",
        location="West Europe",
        network_manager_id=example_network_manager.id,
        display_name="example-pool",
        address_prefixes=["10.0.0.0/24"])
    example = azure.network.get_network_manager_ipam_pool_output(name=example_network_manager_ipam_pool.name,
        network_manager_id=example_network_manager.id)
    pulumi.export("id", example.id)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Microsoft.Network` - 2025-01-01


    :param _builtins.str name: The name of this Network Manager IPAM Pool.
    :param _builtins.str network_manager_id: The ID of the parent Network Manager.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['networkManagerId'] = network_manager_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:network/getNetworkManagerIpamPool:getNetworkManagerIpamPool', __args__, opts=opts, typ=GetNetworkManagerIpamPoolResult)
    return __ret__.apply(lambda __response__: GetNetworkManagerIpamPoolResult(
        address_prefixes=pulumi.get(__response__, 'address_prefixes'),
        description=pulumi.get(__response__, 'description'),
        display_name=pulumi.get(__response__, 'display_name'),
        id=pulumi.get(__response__, 'id'),
        location=pulumi.get(__response__, 'location'),
        name=pulumi.get(__response__, 'name'),
        network_manager_id=pulumi.get(__response__, 'network_manager_id'),
        parent_pool_name=pulumi.get(__response__, 'parent_pool_name'),
        tags=pulumi.get(__response__, 'tags')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetExascaleDatabaseStorageVaultResult',
    'AwaitableGetExascaleDatabaseStorageVaultResult',
    'get_exascale_database_storage_vault',
    'get_exascale_database_storage_vault_output',
]

@pulumi.output_type
class GetExascaleDatabaseStorageVaultResult:
    """
    A collection of values returned by getExascaleDatabaseStorageVault.
    """
    def __init__(__self__, additional_flash_cache_percentage=None, description=None, display_name=None, high_capacity_database_storages=None, id=None, lifecycle_details=None, lifecycle_state=None, location=None, name=None, oci_url=None, ocid=None, resource_group_name=None, time_zone=None, virtual_machine_cluster_count=None, zones=None):
        if additional_flash_cache_percentage and not isinstance(additional_flash_cache_percentage, int):
            raise TypeError("Expected argument 'additional_flash_cache_percentage' to be a int")
        pulumi.set(__self__, "additional_flash_cache_percentage", additional_flash_cache_percentage)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if high_capacity_database_storages and not isinstance(high_capacity_database_storages, list):
            raise TypeError("Expected argument 'high_capacity_database_storages' to be a list")
        pulumi.set(__self__, "high_capacity_database_storages", high_capacity_database_storages)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if lifecycle_details and not isinstance(lifecycle_details, str):
            raise TypeError("Expected argument 'lifecycle_details' to be a str")
        pulumi.set(__self__, "lifecycle_details", lifecycle_details)
        if lifecycle_state and not isinstance(lifecycle_state, str):
            raise TypeError("Expected argument 'lifecycle_state' to be a str")
        pulumi.set(__self__, "lifecycle_state", lifecycle_state)
        if location and not isinstance(location, str):
            raise TypeError("Expected argument 'location' to be a str")
        pulumi.set(__self__, "location", location)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if oci_url and not isinstance(oci_url, str):
            raise TypeError("Expected argument 'oci_url' to be a str")
        pulumi.set(__self__, "oci_url", oci_url)
        if ocid and not isinstance(ocid, str):
            raise TypeError("Expected argument 'ocid' to be a str")
        pulumi.set(__self__, "ocid", ocid)
        if resource_group_name and not isinstance(resource_group_name, str):
            raise TypeError("Expected argument 'resource_group_name' to be a str")
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        if time_zone and not isinstance(time_zone, str):
            raise TypeError("Expected argument 'time_zone' to be a str")
        pulumi.set(__self__, "time_zone", time_zone)
        if virtual_machine_cluster_count and not isinstance(virtual_machine_cluster_count, int):
            raise TypeError("Expected argument 'virtual_machine_cluster_count' to be a int")
        pulumi.set(__self__, "virtual_machine_cluster_count", virtual_machine_cluster_count)
        if zones and not isinstance(zones, list):
            raise TypeError("Expected argument 'zones' to be a list")
        pulumi.set(__self__, "zones", zones)

    @_builtins.property
    @pulumi.getter(name="additionalFlashCachePercentage")
    def additional_flash_cache_percentage(self) -> _builtins.int:
        """
        The size of additional Flash Cache in percentage of High Capacity database storage.
        """
        return pulumi.get(self, "additional_flash_cache_percentage")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Exadata Database Storage Vault description.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="displayName")
    def display_name(self) -> _builtins.str:
        """
        The user-friendly name for the Exadata Database Storage Vault.
        """
        return pulumi.get(self, "display_name")

    @_builtins.property
    @pulumi.getter(name="highCapacityDatabaseStorages")
    def high_capacity_database_storages(self) -> Sequence['outputs.GetExascaleDatabaseStorageVaultHighCapacityDatabaseStorageResult']:
        """
        A `high_capacity_database_storage` block as defined below.
        """
        return pulumi.get(self, "high_capacity_database_storages")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="lifecycleDetails")
    def lifecycle_details(self) -> _builtins.str:
        """
        Additional information about the current lifecycle state.
        """
        return pulumi.get(self, "lifecycle_details")

    @_builtins.property
    @pulumi.getter(name="lifecycleState")
    def lifecycle_state(self) -> _builtins.str:
        """
        Exadata Database Storage Vault lifecycle state enum.
        """
        return pulumi.get(self, "lifecycle_state")

    @_builtins.property
    @pulumi.getter
    def location(self) -> _builtins.str:
        """
        The Azure Region where the Exadata Database Storage Vault exists.
        """
        return pulumi.get(self, "location")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="ociUrl")
    def oci_url(self) -> _builtins.str:
        """
        The URL of the resource in the OCI console.
        """
        return pulumi.get(self, "oci_url")

    @_builtins.property
    @pulumi.getter
    def ocid(self) -> _builtins.str:
        """
        The [OCID](https://docs.oracle.com/en-us/iaas/Content/General/Concepts/identifiers.htm) of the Exadata Database Storage Vault.
        """
        return pulumi.get(self, "ocid")

    @_builtins.property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> _builtins.str:
        return pulumi.get(self, "resource_group_name")

    @_builtins.property
    @pulumi.getter(name="timeZone")
    def time_zone(self) -> _builtins.str:
        """
        The time zone of the Exadata Database Storage Vault.
        """
        return pulumi.get(self, "time_zone")

    @_builtins.property
    @pulumi.getter(name="virtualMachineClusterCount")
    def virtual_machine_cluster_count(self) -> _builtins.int:
        """
        The number of Exadata virtual machine clusters used the Exadata Database Storage Vault.
        """
        return pulumi.get(self, "virtual_machine_cluster_count")

    @_builtins.property
    @pulumi.getter
    def zones(self) -> Sequence[_builtins.str]:
        """
        The Exadata Database Storage Vault Azure zones.
        """
        return pulumi.get(self, "zones")


class AwaitableGetExascaleDatabaseStorageVaultResult(GetExascaleDatabaseStorageVaultResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetExascaleDatabaseStorageVaultResult(
            additional_flash_cache_percentage=self.additional_flash_cache_percentage,
            description=self.description,
            display_name=self.display_name,
            high_capacity_database_storages=self.high_capacity_database_storages,
            id=self.id,
            lifecycle_details=self.lifecycle_details,
            lifecycle_state=self.lifecycle_state,
            location=self.location,
            name=self.name,
            oci_url=self.oci_url,
            ocid=self.ocid,
            resource_group_name=self.resource_group_name,
            time_zone=self.time_zone,
            virtual_machine_cluster_count=self.virtual_machine_cluster_count,
            zones=self.zones)


def get_exascale_database_storage_vault(name: Optional[_builtins.str] = None,
                                        resource_group_name: Optional[_builtins.str] = None,
                                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetExascaleDatabaseStorageVaultResult:
    """
    Use this data source to access information about an existing Exadata Database Storage Vault

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.oracle.get_exascale_database_storage_vault(name="existing",
        resource_group_name="existing")
    pulumi.export("id", example.id)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Oracle.Database` - 2025-09-01


    :param _builtins.str name: The name of this Exadata Database Storage Vault.
    :param _builtins.str resource_group_name: The name of the Resource Group where the Exadata Database Storage Vault exists.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:oracle/getExascaleDatabaseStorageVault:getExascaleDatabaseStorageVault', __args__, opts=opts, typ=GetExascaleDatabaseStorageVaultResult).value

    return AwaitableGetExascaleDatabaseStorageVaultResult(
        additional_flash_cache_percentage=pulumi.get(__ret__, 'additional_flash_cache_percentage'),
        description=pulumi.get(__ret__, 'description'),
        display_name=pulumi.get(__ret__, 'display_name'),
        high_capacity_database_storages=pulumi.get(__ret__, 'high_capacity_database_storages'),
        id=pulumi.get(__ret__, 'id'),
        lifecycle_details=pulumi.get(__ret__, 'lifecycle_details'),
        lifecycle_state=pulumi.get(__ret__, 'lifecycle_state'),
        location=pulumi.get(__ret__, 'location'),
        name=pulumi.get(__ret__, 'name'),
        oci_url=pulumi.get(__ret__, 'oci_url'),
        ocid=pulumi.get(__ret__, 'ocid'),
        resource_group_name=pulumi.get(__ret__, 'resource_group_name'),
        time_zone=pulumi.get(__ret__, 'time_zone'),
        virtual_machine_cluster_count=pulumi.get(__ret__, 'virtual_machine_cluster_count'),
        zones=pulumi.get(__ret__, 'zones'))
def get_exascale_database_storage_vault_output(name: Optional[pulumi.Input[_builtins.str]] = None,
                                               resource_group_name: Optional[pulumi.Input[_builtins.str]] = None,
                                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetExascaleDatabaseStorageVaultResult]:
    """
    Use this data source to access information about an existing Exadata Database Storage Vault

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.oracle.get_exascale_database_storage_vault(name="existing",
        resource_group_name="existing")
    pulumi.export("id", example.id)
    ```

    ## API Providers

    <!-- This section is generated, changes will be overwritten -->
    This data source uses the following Azure API Providers:

    * `Oracle.Database` - 2025-09-01


    :param _builtins.str name: The name of this Exadata Database Storage Vault.
    :param _builtins.str resource_group_name: The name of the Resource Group where the Exadata Database Storage Vault exists.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('azure:oracle/getExascaleDatabaseStorageVault:getExascaleDatabaseStorageVault', __args__, opts=opts, typ=GetExascaleDatabaseStorageVaultResult)
    return __ret__.apply(lambda __response__: GetExascaleDatabaseStorageVaultResult(
        additional_flash_cache_percentage=pulumi.get(__response__, 'additional_flash_cache_percentage'),
        description=pulumi.get(__response__, 'description'),
        display_name=pulumi.get(__response__, 'display_name'),
        high_capacity_database_storages=pulumi.get(__response__, 'high_capacity_database_storages'),
        id=pulumi.get(__response__, 'id'),
        lifecycle_details=pulumi.get(__response__, 'lifecycle_details'),
        lifecycle_state=pulumi.get(__response__, 'lifecycle_state'),
        location=pulumi.get(__response__, 'location'),
        name=pulumi.get(__response__, 'name'),
        oci_url=pulumi.get(__response__, 'oci_url'),
        ocid=pulumi.get(__response__, 'ocid'),
        resource_group_name=pulumi.get(__response__, 'resource_group_name'),
        time_zone=pulumi.get(__response__, 'time_zone'),
        virtual_machine_cluster_count=pulumi.get(__response__, 'virtual_machine_cluster_count'),
        zones=pulumi.get(__response__, 'zones')))
